==> vokoscreen_1.9.0.orig.tar.gz: vokoscreen-1.9.0/language/vokoscreen_ro.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ro" version="2.0">
<context>
    <name>QvkMail</name>
    <message>
        <source>Mail last Video</source>
        <translation>Trimite pe email ultimul video</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Email cu unul sau mai multe fișiere video selectate</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Trimite</translation>
    </message>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Gasești fișierul video ca atașament</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Selectează unul sau mai multe fișiere</translation>
    </message>
</context>
<context>
    <name>QvkWebcam</name>
    <message>
        <source>Noborder</source>
        <translation>Fără margine</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Margine</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Închide</translation>
    </message>
</context>
<context>
    <name>QvkWebcamController</name>
    <message>
        <source>Webcam</source>
        <translation>Cameră Web</translation>
    </message>
    <message>
        <source>Device is busy</source>
        <translation>Dispozitivul este ocupat</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Alege camera web</translation>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Pe tot ecranul</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Fereastră</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Arie</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Mărire</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Implicit</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Codec</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Nu înregistra cursorul de maus</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Calea video</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Lector</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Vokoscreen va fi minimizat cănd începe înregistrarea</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Începe</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Oprește</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauză</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Redă</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Trimite</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Durata înregistrării</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Mărimea în KB</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Aria de ecran pentru înregistrare </translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Setări fps</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Deschide dosar</translation>
    </message>
    <message>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Numărătoare inversă</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Redă ultimul video</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Trimite video</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Selectează unul sau mai multe dispozitive</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Cadre reale pe secundă</translation>
    </message>
    <message>
        <source>Device %1 is busy</source>
        <translation>Diszpozitivul %1 este ocupat</translation>
    </message>
    <message>
        <source>Your Actual frames in the Settings is too heigh</source>
        <translation>Valoarea pentru cadre în Setări este prea mare</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Pagină web</translation>
    </message>
    <message>
        <source>Mailinglist</source>
        <translation>Listă de discuții</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Suport</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Dezvoltator</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Cadre</translation>
    </message>
    <message>
        <source>Beta openSUSE</source>
        <translation>Beta openSUSE</translation>
    </message>
    <message>
        <source>Beta Ubuntu</source>
        <translation>Beta Ubuntu</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donează</translation>
    </message>
    <message>
        <source>Program for recording</source>
        <translation>Program pentru înregistrare</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Traduceri</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show in systray</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>New version available</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> vokoscreen_2.1.0.orig.tar.gz: vokoscreen-2.1.0/language/vokoscreen_ro.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ro" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Dispozitivul este ocupat</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>Trimite pe email ultimul video</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Email cu unul sau mai multe fișiere video selectate</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Trimite</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Găsești fișierul video ca atașament</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Selectează unul sau mai multe fișiere</translation>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>Margine</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Închide</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Dispozitivul este ocupat</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Pe tot ecranul</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Fereastră</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Arie</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Mărire</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Implicit</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Codec</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Nu înregistra cursorul de maus</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Calea video</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Lector</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Vokoscreen va fi minimizat când începe înregistrarea</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Începe</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Oprește</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauză</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Redă</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Trimite</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Durata înregistrării</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Mărimea în KB</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Aria de ecran pentru înregistrare</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Setări fps</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Deschide dosar</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Numărătoare inversă</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Redă ultimul video</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Trimite video</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Selectează unul sau mai multe dispozitive</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Cadre reale pe secundă</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Pagină web</translation>
    </message>
    <message>
        <source>Mailinglist</source>
        <translation>Listă de discuții</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Suport</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Dezvoltator</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Cadre</translation>
    </message>
    <message>
        <source>Beta openSUSE</source>
        <translation>Beta openSUSE</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donează</translation>
    </message>
    <message>
        <source>Program for recording</source>
        <translation>Program pentru înregistrare</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Traduceri</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Cod sursă</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Arată în tava de sistem</translation>
    </message>
    <message>
        <source>New version available</source>
        <translation>O nouă versiune este disponibilă</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Codec video</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Codec audio</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Cameră Web</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Alege camera web</translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Display</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All Displays</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
